pub struct Map<K, V> { /* private fields */ }Expand description
Simple CRDT Map
This types defines a CRDT for a map from keys to values. Values are CRDT types which can have their own updating logic.
Internally, the map is stored as a vector of keys and values, sorted by ascending key order.
This is why the key type K must implement Ord (and also to ensure a unique serialization,
such that two values can be compared for equality based on their hashes). As a consequence,
insertions take O(n) time. This means that Map should be used for reasonably small maps.
However, note that even if we were using a more efficient data structure such as a BTreeMap,
the serialization cost O(n) would still have to be paid at each modification, so we are
actually not losing anything here.
Implementations
Sourceimpl<K, V> Map<K, V>
impl<K, V> Map<K, V>
Sourcepub fn put_mutator(k: K, v: V) -> Map<K, V>
pub fn put_mutator(k: K, v: V) -> Map<K, V>
Returns a map that contains a single mapping from the specified key to the specified value. This can be used to build a delta-mutator: when merged with another map, the value will be added or CRDT-merged if a previous value already exists.